@@ -5,12 +5,15 @@
 #include <boost/test/unit_test.hpp>
 
 #include "Buffer.hpp"
-#include "MaeParser.hpp"
 #include "MaeBlock.hpp"
+#include "MaeConstants.hpp"
+#include "MaeParser.hpp"
 
 using namespace schrodinger;
 using namespace schrodinger::mae;
 
+using std::shared_ptr;
+
 using boost::trim_copy;
 
 static std::string get_string(IndexedBlockBuffer& indexed_block_buffer,
@@ -38,14 +41,14 @@ BOOST_AUTO_TEST_CASE(OuterBlockBeginning)
         Buffer b(ss);
         b.load();
         std::string name = outer_block_beginning(b);
-        BOOST_REQUIRE_EQUAL(name, "f_m_ct");
+        BOOST_REQUIRE_EQUAL(name, CT_BLOCK);
     }
     {
         std::stringstream ss("f_m_ct{");
         Buffer b(ss);
         b.load();
         std::string name = outer_block_beginning(b);
-        BOOST_REQUIRE_EQUAL(name, "f_m_ct");
+        BOOST_REQUIRE_EQUAL(name, CT_BLOCK);
     }
     {
         // TODO: Check that this is actually the desired behavior; I'm not
@@ -60,7 +63,6 @@ BOOST_AUTO_TEST_CASE(OuterBlockBeginning)
 
 BOOST_AUTO_TEST_CASE(OuterBlockBeginErrors)
 {
-    std::string name;
     {
         std::stringstream ss("b_m_ct {");
         Buffer b(ss);
@@ -69,9 +71,10 @@ BOOST_AUTO_TEST_CASE(OuterBlockBeginErrors)
             std::string name = outer_block_beginning(b);
             BOOST_FAIL("Expected an exception.");
         } catch (read_exception& e) {
-            BOOST_REQUIRE_EQUAL(trim_copy(std::string(e.what())), "Line 1, column 1: "
-                                          "Bad format for outer block name; "
-                                          "must be (f|p)_<author>_<name>.");
+            BOOST_REQUIRE_EQUAL(trim_copy(std::string(e.what())),
+                                "Line 1, column 1: "
+                                "Bad format for outer block name; "
+                                "must be (f|p)_<author>_<name>.");
         }
     }
     {
@@ -82,9 +85,10 @@ BOOST_AUTO_TEST_CASE(OuterBlockBeginErrors)
             std::string name = outer_block_beginning(b);
             BOOST_FAIL("Expected an exception.");
         } catch (read_exception& e) {
-            BOOST_REQUIRE_EQUAL(trim_copy(std::string(e.what())), "Line 1, column 4: "
-                                          "Bad format for outer block name; "
-                                          "must be (f|p)_<author>_<name>.");
+            BOOST_REQUIRE_EQUAL(trim_copy(std::string(e.what())),
+                                "Line 1, column 4: "
+                                "Bad format for outer block name; "
+                                "must be (f|p)_<author>_<name>.");
         }
     }
     {
@@ -95,9 +99,10 @@ BOOST_AUTO_TEST_CASE(OuterBlockBeginErrors)
             std::string name = outer_block_beginning(b);
             BOOST_FAIL("Expected an exception.");
         } catch (read_exception& e) {
-            BOOST_REQUIRE_EQUAL(trim_copy(std::string(e.what())), "Line 1, column 2: "
-                                          "Bad format for outer block name; "
-                                          "must be (f|p)_<author>_<name>.");
+            BOOST_REQUIRE_EQUAL(trim_copy(std::string(e.what())),
+                                "Line 1, column 2: "
+                                "Bad format for outer block name; "
+                                "must be (f|p)_<author>_<name>.");
         }
     }
     {
@@ -108,8 +113,9 @@ BOOST_AUTO_TEST_CASE(OuterBlockBeginErrors)
             std::string name = outer_block_beginning(b);
             BOOST_FAIL("Expected an exception.");
         } catch (read_exception& e) {
-            BOOST_REQUIRE_EQUAL(trim_copy(std::string(e.what())), "Line 1, column 10: "
-                                          "Missing '{' for outer block.");
+            BOOST_REQUIRE_EQUAL(trim_copy(std::string(e.what())),
+                                "Line 1, column 10: "
+                                "Missing '{' for outer block.");
         }
     }
 }
@@ -117,7 +123,7 @@ BOOST_AUTO_TEST_CASE(OuterBlockBeginErrors)
 BOOST_AUTO_TEST_CASE(BlockBeginning)
 {
     {
-        std::stringstream ss("m_something {");
+        auto ss = std::make_shared<std::stringstream>("m_something {");
         int indexed = 0;
         MaeParser mp(ss);
         std::string name = mp.blockBeginning(&indexed);
@@ -125,7 +131,7 @@ BOOST_AUTO_TEST_CASE(BlockBeginning)
         BOOST_REQUIRE_EQUAL(indexed, 0);
     }
     {
-        std::stringstream ss("mmmm_block{");
+        auto ss = std::make_shared<std::stringstream>("mmmm_block{");
         int indexed = 0;
         MaeParser mp(ss);
         std::string name = mp.blockBeginning(&indexed);
@@ -133,7 +139,7 @@ BOOST_AUTO_TEST_CASE(BlockBeginning)
         BOOST_REQUIRE_EQUAL(indexed, 0);
     }
     {
-        std::stringstream ss("m_whatev[23]{");
+        auto ss = std::make_shared<std::stringstream>("m_whatev[23]{");
         int indexed = 0;
         MaeParser mp(ss);
         std::string name = mp.blockBeginning(&indexed);
@@ -146,7 +152,7 @@ BOOST_AUTO_TEST_CASE(BlockBeginningErrors)
 {
     {
         try {
-            std::stringstream ss("");
+            auto ss = std::make_shared<std::stringstream>("");
             int indexed = 0;
             MaeParser mp(ss);
             mp.blockBeginning(&indexed);
@@ -160,43 +166,47 @@ BOOST_AUTO_TEST_CASE(BlockBeginningErrors)
     }
     {
         try {
-            std::stringstream ss("m_block[integer]");
+            auto ss = std::make_shared<std::stringstream>("m_block[integer]");
             int indexed = 0;
             MaeParser mp(ss);
             mp.blockBeginning(&indexed);
             BOOST_FAIL("Expected an exception.");
         } catch (read_exception& e) {
-            BOOST_REQUIRE_EQUAL(trim_copy(std::string(e.what())), "Line 1, column 9: "
-                                          "Unexpected character.");
+            BOOST_REQUIRE_EQUAL(trim_copy(std::string(e.what())),
+                                "Line 1, column 9: "
+                                "Unexpected character.");
         }
     }
     {
         try {
-            std::stringstream ss("m_block[33  ");
+            auto ss = std::make_shared<std::stringstream>("m_block[33  ");
             int indexed = 0;
             MaeParser mp(ss);
             mp.blockBeginning(&indexed);
             BOOST_FAIL("Expected an exception.");
         } catch (read_exception& e) {
-            BOOST_REQUIRE_EQUAL(trim_copy(std::string(e.what())), "Line 1, column 13: "
-                                          "Bad block index; missing ']'.");
+            BOOST_REQUIRE_EQUAL(trim_copy(std::string(e.what())),
+                                "Line 1, column 13: "
+                                "Bad block index; missing ']'.");
         }
     }
     {
         try {
-            std::stringstream ss("m_block[33]  s_m_foo");
+            auto ss =
+                std::make_shared<std::stringstream>("m_block[33]  s_m_foo");
             int indexed = 0;
             MaeParser mp(ss);
             mp.blockBeginning(&indexed);
             BOOST_FAIL("Expected an exception.");
         } catch (read_exception& e) {
-            BOOST_REQUIRE_EQUAL(trim_copy(std::string(e.what())), "Line 1, column 14: "
-                                          "Missing '{' for block.");
+            BOOST_REQUIRE_EQUAL(trim_copy(std::string(e.what())),
+                                "Line 1, column 14: "
+                                "Missing '{' for block.");
         }
     }
     {
         try {
-            std::stringstream ss("'bad_block");
+            auto ss = std::make_shared<std::stringstream>("'bad_block");
             int indexed = 0;
             MaeParser mp(ss);
             mp.blockBeginning(&indexed);
@@ -210,7 +220,7 @@ BOOST_AUTO_TEST_CASE(BlockBeginningErrors)
     }
     {
         try {
-            std::stringstream ss("mmmm_ ");
+            auto ss = std::make_shared<std::stringstream>("mmmm_ ");
             int indexed = 0;
             MaeParser mp(ss);
             mp.blockBeginning(&indexed);
@@ -228,24 +238,27 @@ BOOST_AUTO_TEST_CASE(BlockBody)
 {
     double tolerance = std::numeric_limits<double>::epsilon();
     {
-        std::stringstream ss("b_m_foo b_m_bar::: 1 0 }");
+        auto ss =
+            std::make_shared<std::stringstream>("b_m_foo b_m_bar::: 1 0 }");
         MaeParser mp(ss);
-        auto bl = mp.blockBody(std::string("f_m_ct"));
+        auto bl = mp.blockBody(CT_BLOCK);
         BOOST_REQUIRE(bl->getBoolProperty("b_m_foo"));
         BOOST_REQUIRE(!bl->getBoolProperty("b_m_bar"));
     }
     {
-        std::stringstream ss(" b_m_foo b_m_bar ::: 1 0 }");
+        auto ss =
+            std::make_shared<std::stringstream>(" b_m_foo b_m_bar ::: 1 0 }");
         MaeParser mp(ss);
-        auto bl = mp.blockBody(std::string("f_m_ct"));
+        auto bl = mp.blockBody(CT_BLOCK);
         BOOST_REQUIRE(bl->getBoolProperty("b_m_foo"));
         BOOST_REQUIRE(!bl->getBoolProperty("b_m_bar"));
     }
     {
-        std::stringstream ss(" b_m_foo b_m_bar s_m_foo r_m_foo i_m_foo ::: "
-                             " 1       0       svalue  3.1415  22 }");
+        auto ss = std::make_shared<std::stringstream>(
+            " b_m_foo b_m_bar s_m_foo r_m_foo i_m_foo ::: "
+            " 1       0       svalue  3.1415  22 }");
         MaeParser mp(ss);
-        auto bl = mp.blockBody(std::string("f_m_ct"));
+        auto bl = mp.blockBody(CT_BLOCK);
         BOOST_REQUIRE(bl->getBoolProperty("b_m_foo"));
         BOOST_REQUIRE(!bl->getBoolProperty("b_m_bar"));
         BOOST_REQUIRE_EQUAL(bl->getStringProperty("s_m_foo"), "svalue");
@@ -257,14 +270,16 @@ BOOST_AUTO_TEST_CASE(BlockBody)
 BOOST_AUTO_TEST_CASE(BlockBodyErrors)
 {
     {
-        std::stringstream ss(" b_m_foo\n s_m_foo\n r_m_foo\n i_m_foo\n :::\n"
-                             " 1\n svalue\n 3.1415\n 22\n ");
+        auto ss = std::make_shared<std::stringstream>(
+            " b_m_foo\n s_m_foo\n r_m_foo\n i_m_foo\n :::\n"
+            " 1\n svalue\n 3.1415\n 22\n ");
         MaeParser mp(ss);
         try {
-            mp.blockBody(std::string("f_m_ct"));
+            mp.blockBody(CT_BLOCK);
         } catch (read_exception& e) {
-            BOOST_REQUIRE_EQUAL(trim_copy(std::string(e.what())), "Line 10, column 2: "
-                                          "Missing '}' for block.");
+            BOOST_REQUIRE_EQUAL(trim_copy(std::string(e.what())),
+                                "Line 10, column 2: "
+                                "Missing '}' for block.");
         }
     }
 }
@@ -272,25 +287,25 @@ BOOST_AUTO_TEST_CASE(BlockBodyErrors)
 BOOST_AUTO_TEST_CASE(Property)
 {
     {
-        std::stringstream ss("b_m_foo ");
+        auto ss = std::make_shared<std::stringstream>("b_m_foo ");
         MaeParser mp(ss);
         auto p = mp.property();
         BOOST_REQUIRE(*p == "b_m_foo");
     }
     {
-        std::stringstream ss("r_m_bar ");
+        auto ss = std::make_shared<std::stringstream>("r_m_bar ");
         MaeParser mp(ss);
         auto p = mp.property();
         BOOST_REQUIRE(*p == "r_m_bar");
     }
     {
-        std::stringstream ss("b_st_1_2_3_4_R_5 ");
+        auto ss = std::make_shared<std::stringstream>("b_st_1_2_3_4_R_5 ");
         MaeParser mp(ss);
         auto p = mp.property();
         BOOST_REQUIRE(*p == "b_st_1_2_3_4_R_5");
     }
     {
-        std::stringstream ss("s_author_name ");
+        auto ss = std::make_shared<std::stringstream>("s_author_name ");
         MaeParser mp(ss);
         auto p = mp.property();
         BOOST_REQUIRE(*p == "s_author_name");
@@ -300,7 +315,7 @@ BOOST_AUTO_TEST_CASE(Property)
 BOOST_AUTO_TEST_CASE(PropertyValueSeparator)
 {
     {
-        std::stringstream ss(":::");
+        auto ss = std::make_shared<std::stringstream>(":::");
         MaeParser mp(ss);
         auto p = mp.property();
         BOOST_REQUIRE(p == nullptr);
@@ -311,7 +326,7 @@ BOOST_AUTO_TEST_CASE(PropertyList)
 {
     {
         std::vector<std::string> properties;
-        std::stringstream ss("b_m_foo s_j_bar :::");
+        auto ss = std::make_shared<std::stringstream>("b_m_foo s_j_bar :::");
         // Buffer size of 14 was chosen to reproduce a bug during development;
         // a buffer boundary in the name part of the key.
         MaeParser mp(ss, 14u);
@@ -329,7 +344,7 @@ BOOST_AUTO_TEST_CASE(PropertyList)
     }
     {
         std::vector<std::string> properties;
-        std::stringstream ss("b_m_foo s_j_ :::");
+        auto ss = std::make_shared<std::stringstream>("b_m_foo s_j_ :::");
         MaeParser mp(ss);
         try {
             while (true) {
@@ -354,7 +369,7 @@ BOOST_AUTO_TEST_CASE(PropertyErrors)
 {
     {
         try {
-            std::stringstream ss("bo_m_foo ");
+            auto ss = std::make_shared<std::stringstream>("bo_m_foo ");
             MaeParser mp(ss);
             mp.property();
             BOOST_FAIL("Expected an exception.");
@@ -367,7 +382,7 @@ BOOST_AUTO_TEST_CASE(PropertyErrors)
     }
     {
         try {
-            std::stringstream ss("x_m_foo ");
+            auto ss = std::make_shared<std::stringstream>("x_m_foo ");
             MaeParser mp(ss);
             mp.property();
             BOOST_FAIL("Expected an exception.");
@@ -380,7 +395,7 @@ BOOST_AUTO_TEST_CASE(PropertyErrors)
     }
     {
         try {
-            std::stringstream ss("s_m_");
+            auto ss = std::make_shared<std::stringstream>("s_m_");
             MaeParser mp(ss);
             mp.property();
             BOOST_FAIL("Expected an exception.");
@@ -393,7 +408,7 @@ BOOST_AUTO_TEST_CASE(PropertyErrors)
     }
     {
         try {
-            std::stringstream ss("s_m_ ");
+            auto ss = std::make_shared<std::stringstream>("s_m_ ");
             MaeParser mp(ss);
             mp.property();
             BOOST_FAIL("Expected an exception.");
@@ -424,9 +439,13 @@ BOOST_AUTO_TEST_CASE(Integer)
         BOOST_REQUIRE_EQUAL(parse_value<int>(b), 2147483647);
     }
     {
-        std::stringstream ss("-2147483648");
+        // There is a bug in some VS editions that raises warning C4146
+        // when assigning -2147483648 to an int in code..
+        const int reference = std::numeric_limits<int>::min();
+        std::stringstream ss;
+        ss << reference;
         Buffer b(ss);
-        BOOST_REQUIRE_EQUAL(parse_value<int>(b), -2147483648);
+        BOOST_REQUIRE_EQUAL(parse_value<int>(b), reference);
     }
 }
 
@@ -518,8 +537,9 @@ BOOST_AUTO_TEST_CASE(RealErrors)
             parse_value<double>(b);
             BOOST_FAIL("Expected an exception.");
         } catch (read_exception& e) {
-            BOOST_REQUIRE_EQUAL(trim_copy(std::string(e.what())), "Line 1, column 1: "
-                                          "Missing real.");
+            BOOST_REQUIRE_EQUAL(trim_copy(std::string(e.what())),
+                                "Line 1, column 1: "
+                                "Missing real.");
         }
     }
     {
@@ -542,8 +562,9 @@ BOOST_AUTO_TEST_CASE(RealErrors)
             parse_value<double>(b);
             BOOST_FAIL("Expected an exception.");
         } catch (read_exception& e) {
-            BOOST_REQUIRE_EQUAL(trim_copy(std::string(e.what())), "Line 2, column 6: "
-                                          "Bad real number.");
+            BOOST_REQUIRE_EQUAL(trim_copy(std::string(e.what())),
+                                "Line 2, column 6: "
+                                "Bad real number.");
         }
     }
     {
@@ -559,7 +580,8 @@ BOOST_AUTO_TEST_CASE(RealErrors)
             BOOST_FAIL("Expected an exception.");
         } catch (read_exception& e) {
             BOOST_REQUIRE_MESSAGE(
-                trim_copy(std::string(e.what())) == valid_error1 || trim_copy(std::string(e.what())) == valid_error2,
+                trim_copy(std::string(e.what())) == valid_error1 ||
+                    trim_copy(std::string(e.what())) == valid_error2,
                 "Expected " << valid_error1 << " or " << valid_error2
                             << " but got " << e.what());
         }
@@ -587,7 +609,7 @@ BOOST_AUTO_TEST_CASE(String)
         Buffer b(ss);
         whitespace(b);
         std::string s = parse_value<std::string>(b);
-        BOOST_REQUIRE_EQUAL(s, "Q\\ Z");
+        BOOST_REQUIRE_EQUAL(s, R"(Q Z)");
     }
     {
         std::stringstream ss(R"("a b c d e")");
@@ -629,13 +651,15 @@ BOOST_AUTO_TEST_CASE(Boolean)
         std::stringstream ss(" 1");
         Buffer b(ss);
         whitespace(b);
-        BOOST_REQUIRE_EQUAL(parse_value<bool>(b), true);
+        BOOST_REQUIRE_EQUAL(parse_value<BoolProperty>(b),
+                            static_cast<BoolProperty>(true));
     }
     {
         std::stringstream ss("0 ");
         Buffer b(ss);
         whitespace(b);
-        BOOST_REQUIRE_EQUAL(parse_value<bool>(b), false);
+        BOOST_REQUIRE_EQUAL(parse_value<BoolProperty>(b),
+                            static_cast<BoolProperty>(false));
     }
 }
 
@@ -646,7 +670,7 @@ BOOST_AUTO_TEST_CASE(BooleanErrors)
             std::stringstream ss("\n\n\na");
             Buffer b(ss);
             whitespace(b);
-            parse_value<bool>(b);
+            parse_value<BoolProperty>(b);
             BOOST_FAIL("Expected an exception.");
         } catch (read_exception& e) {
             BOOST_REQUIRE_EQUAL(trim_copy(std::string(e.what())),
@@ -659,7 +683,7 @@ BOOST_AUTO_TEST_CASE(BooleanErrors)
             std::stringstream ss("\t\n\n11");
             Buffer b(ss);
             whitespace(b);
-            parse_value<bool>(b);
+            parse_value<BoolProperty>(b);
             BOOST_FAIL("Expected an exception.");
         } catch (read_exception& e) {
             BOOST_REQUIRE_EQUAL(trim_copy(std::string(e.what())),
